@@ -7,7 +7,8 @@ from channel_app.core.data import (CategoryTreeDto, CategoryNodeDto,
                                    CategoryDto,
                                    CategoryAttributeDto,
                                    CategoryAttributeValueDto, ErrorReportDto,
-                                   ChannelConfSchemaField)
+                                   ChannelConfSchemaField, AttributeDto,
+                                   AttributeValueDto)
 from channel_app.core.utilities import mock_response_decorator
 from channel_app.omnitron.constants import ChannelConfSchemaDataTypes
 
@@ -915,6 +916,66 @@ class GetCategoryAttributes(ChannelCommandInterface):
         }
 
 
+class GetAttributes(ChannelCommandInterface):
+    """
+    It is the class that enables the creation of attribute and attribute values
+    without depending on category.
+    """
+
+    def get_data(self):
+        data = self.objects
+        return data
+
+    def validated_data(self, data) -> object:
+        return data
+
+    def transform_data(self, data) -> object:
+        return data
+
+    def send_request(self, transformed_data) -> object:
+        response = self.__mocked_request(data=transformed_data)
+        return response
+
+    def normalize_response(self, data, validated_data, transformed_data,
+                           response) -> Tuple[
+        List[AttributeDto], ErrorReportDto, Any]:
+        """
+        It is the method where the response
+        from the Channel is processed and
+        AttributeDto and AttributeValueDto are created.
+        """
+        report = self.create_report(response)
+
+        response = response.json()
+        attributes = []
+        for attribute in response:
+            attr = AttributeDto(remote_id=attribute["id"],
+                                name=attribute["name"],
+                                values=[])
+            for attribute_value in attribute["attr_values"]:
+                attr.values.append(
+                    AttributeValueDto(remote_id=attribute_value["id"],
+                                      name=attribute_value["name"]))
+            attributes.append(attr)
+
+        return attributes, report, data
+
+    @mock_response_decorator
+    def __mocked_request(self, data):
+        """
+        Mock a request and response for the send operation to mimic actual channel data
+        """
+
+        return [{
+            "id": 123213,
+            "name": "Color",
+            "attr_values": [{"id": 213124,
+                             "name": "Green"},
+                            {"id": 21442,
+                             "name": "Red"}]
+        }]
+
+
 class GetChannelConfSchema(ChannelCommandInterface):
     """
     Prepare channel conf schema
